/*
** ===================================================================
** Nzev souboru   : lcd_c.c
** Mikrokontroler  : ATmega16
** Popis           : Funkce pro ovldn lcd displeje
**		   : MC0802A-SYL/H s radicem ST7066U (pro hardware lihen)
** Autor           : Peter Fleury ( http://homepage.hispeed.ch/peterfleury/ )
**                 : Tom Frza ( fryza@feec.vutbr.cz )
**		   : Thomas Breining (breinint@esiee.fr)
**		   : Jan Vlim
** ===================================================================
*/


/*
** Hlavikov soubory
*/
#include <avr/io.h>			// hlavikov soubor pro mikrokontrolr ATmega16
#define F_CPU 16000000UL	// frekvence hodinovho signlu (nutn pro delay.h)
#include <util/delay.h>     // hlavikov soubor pro zpodn
#include "lcd_h.h"          // hlavikov soubor pro obsluhu lcd


/*
** Globln promnn
*/
unsigned char x,y ;			// pomocn souadnice pozice kurzoru



/*
** ===================================================================
**     Nzev funkce  : lcd_clrscr
**
**     Popis         :
**         Smazn obsahu lcd displeje.
**     Parametry     : dn
**     Vst. hodnota : dn
** ===================================================================
*/
void lcd_clrscr( void )
{
	lcd_command( 0x00000001 ) ;
	x = 0 ;
	y = 0 ;
	_delay_ms( 16 ) ;
}
/*
** ===================================================================
**     Nzev funkce  : lcd_command
**
**     Popis         :
**         Zpis 1bytov instrukce do lcd displeje.
**     Parametry     : data - instrukce pro lcd diplej
**     Vst. hodnota : dn
** ===================================================================
*/
void lcd_command( char data )
{
	lcd_write( data, 0 ) ;
}
/*
** ===================================================================
**     Nzev funkce  : lcd_data
**
**     Popis         :
**         Zpis 1bytovho datovho slova do lcd displeje.
**     Parametry     : data - data pro lcd displej
**     Vst. hodnota : dn
** ===================================================================
*/
void lcd_data( char data )
{
	lcd_write( data, 1 ) ;
}
/*
** ===================================================================
**     Nzev funkce  : lcd_write
**
**     Popis         :
**         Zpis instrukce nebo dat do lcd displeje.
**     Parametry     : data - instrukce/data pro lcd diplej
**                     rs   - 0: instrukce; 1: data
**     Vst. hodnota : dn
** ===================================================================
*/
void lcd_write( char data, char rs )
{
	unsigned char temp ;

    if( rs ) lcd_rs_high() ;
	else lcd_rs_low() ;

	//zjisteni hodnoty nulteho bitu dat a prevedeni do lcd
	temp = data & 0b00000001;
	if(temp == 1) LCD_PORT1 |= _BV(LCD_DB0);
	else LCD_PORT1 &= ~(_BV(LCD_DB0));

	//zjisteni hodnoty prvniho bitu dat a prevedeni do lcd
	temp = data & 0b00000010;
	if(temp == 2) LCD_PORT1 |= _BV(LCD_DB1);
	else LCD_PORT1 &= ~(_BV(LCD_DB1));
	
	temp = data & 0b00000100;
	if(temp == 4) LCD_PORT2 |= _BV(LCD_DB2);
	else LCD_PORT2 &= ~(_BV(LCD_DB2));	

	temp = data & 0b00001000;
	if(temp == 8) LCD_PORT1 |= _BV(LCD_DB3);
	else LCD_PORT1 &= ~(_BV(LCD_DB3));

	temp = data & 0b00010000;
	if(temp == 16) LCD_PORT2 |= _BV(LCD_DB4);
	else LCD_PORT2 &= ~(_BV(LCD_DB4));
	
	temp = data & 0b00100000;
	if(temp == 32) LCD_PORT2 |= _BV(LCD_DB5);
	else LCD_PORT2 &= ~(_BV(LCD_DB5));	

	temp = data & 0b01000000;
	if(temp == 64) LCD_PORT2 |= _BV(LCD_DB6);
	else LCD_PORT2 &= ~(_BV(LCD_DB6));

	temp = data & 0b10000000;
	if(temp == 128) LCD_PORT2 |= _BV(LCD_DB7);
	else LCD_PORT2 &= ~(_BV(LCD_DB7));

	lcd_e_toggle() ;
	_delay_ms( 2 ) ;

	//temp = LCD_PORT & 0x0f ;
    //LCD_PORT = temp | ( data & 0xf0 ) ;
    //lcd_e_toggle() ;
    //LCD_PORT = temp | (( data & 0x0f ) << 4 ) ;
    //lcd_e_toggle() ;
    //LCD_PORT = temp | 0xf0 ;
    //_delay_ms( 2 ) ;
}
/*
** ===================================================================
**     Nzev funkce  : toggle_e
**
**     Popis         :
**         Realizace jednoho "enable" pulsu pro lcd displej.
**     Parametry     : dn
**     Vst. hodnota : dn
** ===================================================================
*/
void toggle_e( void )
{
    lcd_e_high() ;
    lcd_e_delay() ;
    lcd_e_low() ;
}
/*
** ===================================================================
**     Nzev funkce  : lcd_gotoxy
**
**     Popis         :
**         Pesun kurzoru na pozici x,y lcd displeje.
**     Parametry     : x_,y_ - nov pozice kurzoru lcd displeje
**     Vst. hodnota : dn
** ===================================================================
*/
void lcd_gotoxy( char x_, char y_ )
{
	if( y_ == 0 )
    {	lcd_command(( 1<<LCD_DDRAM ) + LCD_START_LINE1 + x_ ) ;
		y = 0 ;
	}
    else if( y_ == 1 )
    {	lcd_command(( 1<<LCD_DDRAM ) + LCD_START_LINE2 + x_ ) ;
		y = 1 ;
	}
	
	x = x_ ;
}
/*
** ===================================================================
**     Nzev funkce  : lcd_putc
**
**     Popis         :
**         Zobrazen jednoho znaku na lcd displeji.
**     Parametry     : c - znak k zobrazen na lcd displeji
**     Vst. hodnota : dn
** ===================================================================
*/
void lcd_putc( char c )
{
    if (c=='\n')
		lcd_newline() ;
	else
	{
        if(( x == LCD_DISP_LENGTH ) && ( y == 0 ))
			lcd_secondline() ;
		else if(( x == LCD_DISP_LENGTH ) && ( y == 1 ))
			lcd_firstline() ;
	    lcd_data( c ) ;
		x++ ;
	}
}


/*
** ===================================================================
**     Nzev funkce  : lcd_puts
**
**     Popis         :
**         Zobrazen etzce znak na lcd displeji.
**     Parametry     : *s - ukazatel na etzec znak
**     Vst. hodnota : dn
** ===================================================================
*/
void lcd_puts( const char *s )
{
    register char c ;

    while(( c = *s++ ))
        lcd_putc( c ) ;
}


/*
** ===================================================================
**     Nzev funkce  : lcd_newline
**
**     Popis         :
**         Skok na nov dek lcd displeje.
**     Parametry     : dn
**     Vst. hodnota : dn
** ===================================================================
*/
void lcd_newline( void )
{
	if( y == 1 && x == 0)
		lcd_firstline() ;
	else if( y == 0 && x == 0)
		lcd_secondline() ;
}


/*
** ===================================================================
**     Nzev funkce  : lcd_firstline
**
**     Popis         :
**         Skok a vymazn prvnho dku lcd displeje.
**     Parametry     : dn
**     Vst. hodnota : dn
** ===================================================================
*/
void lcd_firstline( void )
{
    lcd_command(( 1<<LCD_DDRAM ) + LCD_START_LINE1 ) ;
	x = 0 ;
	y = 0 ;
	lcd_puts( "                " ) ;
    lcd_command(( 1<<LCD_DDRAM ) + LCD_START_LINE1 ) ;
	x = 0 ;
	y = 0 ;
}


/*
** ===================================================================
**     Nzev funkce  : lcd_secondline
**
**     Popis         :
**         Skok a vymazn druhho dku lcd displeje.
**     Parametry     : dn
**     Vst. hodnota : dn
** ===================================================================
*/
void lcd_secondline( void )
{
    lcd_command(( 1<<LCD_DDRAM ) + LCD_START_LINE2 ) ;
	x = 0 ;
	y = 1 ;
	lcd_puts( "                " ) ;
    lcd_command(( 1<<LCD_DDRAM ) + LCD_START_LINE2 ) ;
	x = 0 ;
	y = 1 ;
}

/*
** ===================================================================
**     Nzev funkce  : lcd_init
**
**     Popis         :
**         Inicializace lcd displeje.
**     Parametry     : dn
**     Vst. hodnota : dn
** ===================================================================
*/
void lcd_init( void )
{
	DDRA |= _BV( DDA2 ) | _BV( DDA3 ) | _BV( DDA4 ) | _BV( DDA5 ) | _BV( DDA6 ) | _BV( DDA7 );	//nastaveni smeroveho registru portu A
	DDRC |= _BV( DDC2 ) | _BV( DDC3 ) | _BV( DDC4 ) | _BV( DDC5 ) | _BV( DDC6 ) | _BV( DDC7 );	//nastaveni smeroveho registru portu C				
    _delay_ms( 16 ) ;			
	lcd_command( 0b00111000 ) ; //inicializace 8bitovy zapis, 2 radkovy displej
	lcd_command( 0b00000100 ) ; //smer posuvu kurzoru
	lcd_command( 0b00001100 ) ; //zapnuti displeje
	lcd_clrscr() ; //smaze displej a nastavi kurzor na zacatek
}

/*
** Konec zdrojovho souboru
*/
