/*
** ===================================================================
** Nzev souboru   : lcd_c.c
** Mikrokontroler  : ATmega16
** Popis           : Hlavikov soubor pro komunikaci s lcd displejem
**				   : MC0802A-SYL/H s radicem ST7066U
** Autor           : Peter Fleury ( http://homepage.hispeed.ch/peterfleury/ )
**                 : Tom Frza ( fryza@feec.vutbr.cz )
**		   		   : Thomas Breining (breinint@esiee.fr)
**				   : Jan Vlim
** ===================================================================
*/
#ifndef _LCD_H
#define _LCD_H 1


/*
** Konstanty
*/
#define LCD_PORT1		PORTA	// vstupn port pro lcd displej
#define LCD_PORT2		PORTC	// vstupn port pro lcd displej

#define LCD_DB0			PORTA7	// definice pinu pro datovy bit
#define LCD_DB1			PORTA3	// definice pinu pro datovy bit
#define LCD_DB2			PORTC7	// definice pinu pro datovy bit
#define LCD_DB3			PORTA2	// definice pinu pro datovy bit
#define LCD_DB4			PORTC6	// definice pinu pro datovy bit
#define LCD_DB5			PORTC2	// definice pinu pro datovy bit
#define LCD_DB6			PORTC5	// definice pinu pro datovy bit
#define LCD_DB7			PORTC3	// definice pinu pro datovy bit

#define LCD_RW_PIN		6		// r/w vstup displeje
#define LCD_E_PIN		4		// enable vstup displeje
#define LCD_RS_PIN		5		// rs vstup displeje
#define LCD_DISP_LENGTH	8		// poet znak na dek displeje

#define LCD_DDRAM		7
#define LCD_START_LINE1	0x00	// adresa prvnho znaku na prvnm dku
#define LCD_START_LINE2	0x40	// adresa prvnho znaku na druhm dku

#define DDR( x )		( *(&x - 1) )	// adresa smrovho registru portu
#define lcd_rw_high()	LCD_PORT1 |=  _BV( LCD_RW_PIN )
#define lcd_rw_low()	LCD_PORT1 &= ~_BV( LCD_RW_PIN )
#define lcd_e_delay()	__asm__ __volatile__( "nop\n nop\n nop" )
#define lcd_e_high()	LCD_PORT1  |=  _BV( LCD_E_PIN )
#define lcd_e_low()		LCD_PORT1  &= ~_BV( LCD_E_PIN )
#define lcd_e_toggle()	toggle_e()
#define lcd_rs_high()	LCD_PORT1 |=  _BV( LCD_RS_PIN )
#define lcd_rs_low()	LCD_PORT1 &= ~_BV( LCD_RS_PIN )


/*
** Prototypy funkc
*/
void lcd_init( void ) ;			// inicializace lcd displeje
void lcd_clrscr( void ) ;		// vymazn obsahu displeje
void lcd_command( char ) ;		// zpis 1bytov instrukce do lcd displeje
void lcd_data( char ) ;			// zpis 1bytovho datovho slova do lcd displeje
void lcd_write( char, char ) ;	// zpis instrukce nebo dat do lcd displeje
void toggle_e( void ) ;			// realizace jednoho "enable" pulsu pro lcd displej
void lcd_gotoxy( char, char ) ;	// pesun kurzoru na pozici x,y lcd displeje
void lcd_putc( char c ) ;		// zobrazen jednoho znaku na lcd displeji
void lcd_puts( const char *s ) ;// zobrazen etzce znak na lcd displeji
void lcd_newline( void ) ;		// skok na nov dek lcd displeje
void lcd_firstline( void ) ;	// skok a vymazn prvnho dku lcd displeje
void lcd_secondline( void ) ;	// skok a vymazn druhho dku lcd displeje
void lcd_thirdline( void ) ;
void lcd_fourthline( void ) ;

#endif


/*
** Konec hlavikovho souboru
*/
