/*
** ===================================================================
** Nzev souboru   : lihen_c.c
** Mikrokontroler  : ATmega16
** Popis           : Funkce patrici k main_lihen
** Autor           : Jan Vlim
** ===================================================================
*/


/*
** Hlavikov soubory
*/
#include <avr/io.h>			// knihovna vstupy vystupy
#include "lihen_h.h"		// knihovna pro lihen
#include "twi_lib.h"		// knihovna ke sbernici i2c
/*
** Globln promnn
*/


/*
** ===================================================================
**     Nzev funkce  : nastav_16b_cit_cas
**     Popis         : Funkce nastavuje ridici registry 16 b C/C
** ===================================================================
*/
void nastav_16b_cit_cas(void)	// fce nastavujici citac casovac 1
{
	TCCR1B |= (1<<CS00) | (1<<CS02);	// nastaveni preddelicky 1024
	OCR1A = COMP_REG1A;					// naplneni registru hodnotou takovou aby se preruseni vyvolalo po cca 300ms
	TIMSK |= (1<<OCIE1A) | (1<<TOIE1);	// nastaveni povoleni preruseni pri shode TCNT0 a OCR0 a pri preteceni C/C1
}
/*
** ===================================================================
**     Nzev funkce  : nastav_cit_cas2
**     Popis         : Funkce nastavuje ridici registry 8 b C/C
** ===================================================================
*/
void nastav_cit_cas2(void)	// fce nastavujici citac casovac 2
{
	TCCR2 = (1<<CS22)|(1<<WGM20) |(1<<WGM21)|(1<<COM21);	// preddelicka 64, fast PWM, CO se pri shode vynuluje
	OCR2 = MOT_RYCHL;		// vlozeni konstanty do porovnavaciho registru, cimz se meni otacky motoru
}
/*
** ===================================================================
**     Nzev funkce  : nastav_cit_cas0
**     Popis         : Funkce nastavuje ridici registry 8 b C/C
** ===================================================================
*/
void nastav_cit_cas0(void)	// fce nastavujici citac casovac 2
{
	 //nastaveni C/C0 .. vetracek
	TCCR0 |= (1<<WGM00) | (1<<WGM01) | (1<<COM01) | (1<<CS00) | (1<<CS02);	// pwm_fast, clar OC0 pri shode, preddelicka 1024
}

/*
** ===================================================================
**     Nzev funkce  : nastav_porty
**     Popis         : Funkce nastavuje smerove registry portu
** ===================================================================
*/
void nastav_porty(void)	// funkce nastavy porty mcu
{
	DDRB &= ~(_BV(DDB0)) & ~(_BV(DDB1));	// portB - tlacitka 1,2 
	DDRD &= ~(_BV(DDD5)) & ~(_BV(DDD6));	// portD - tlacitka 3,4
	DDRC |= _BV(DDC4);						// podsviceni lcd
	DDRB &= ~(_BV(DDB2)) & ~(_BV(DDB4));	// portB - tlacitka sw6 mot, sw7 motor 
	DDRB |= _BV(DDB3);						// vystup PWM vetracku
}
/*
** ===================================================================
**     Nzev funkce  : read
**     Popis         : Funkce cteni hodnoty z RTC
** ===================================================================
*/
unsigned char read(unsigned char bunka)				
{
  unsigned char bcd_i;  

  i2c_start_wait(RTC+I2C_WRITE);		// Vysln start bitu, adresy RTC a bitu pro zpis (ten, zpis) (S ADR R/\W)
  i2c_write(bunka);						// Vysln datov adresy ze kter se m st
  i2c_rep_start(RTC+I2C_READ);   		// Vysln znovu start bitu, adresy RTC a bitu pro ten (ten, zpis) (S ADR R/\W)
  bcd_i = i2c_readNak();               	// Peten celho bytu z vyslan adresy (sekund)
  i2c_stop();  
  
  return bcd_i;                       	// Vysln Stop bitu, ukonen komunikace
}
/*
** ===================================================================
**     Nzev funkce  : write
**     Popis         : Funkce pro zapis hodnoty z RTC
** ===================================================================
*/
void write(unsigned char bcd_i, unsigned char bunka)
{	
	i2c_start_wait(RTC+I2C_WRITE);   	// Vysln start bitu, adresy RTC a bitu pro zpis (ten, zpis) (S ADR R/\W)								   	
    i2c_write(bunka);					// vyber adresy(hodiny minuty atd)											   
	i2c_write(bcd_i);						// zapise BCD na vybranou adresu							   
	i2c_stop(); 						// Vysln Stop bitu, ukonen komunikace
}

/*
** Konec zdrojovho souboru
*/
