/*
** ===================================================================
** Nzev souboru   : main_lihen.c
** Mikrokontroler  : ATmega16
** Popis           : Hlavni kod k hardwaru slouzicimu k vytvareni a 
**				   : monitorovani vhodnych podminek k vylihnuti kurat
** Autor           : Jan Vlim
** Verze           : 1.00 (May, 2012)
** ===================================================================
*/

/*
** DEFINICE A KNIHOVNY
*/
#include "lcd_h.h"			// knihovna pro lcd
#include "lihen_h.h"		// knihovna pro lihen
#include <avr/interrupt.h>	// knihovna potrebna pro preruseni
#include "DS18B20.h"		// knihovna pro cidla teploty
#include "twi_lib.h"		// knihovna ke sbernici i2c
#include <stdio.h>			// knihovna k sptintf

/*
** DEKLARACE GLOBALNICH PROMENNYCH
*/
volatile char s_tl_1=0, s_tl_2=0, s_tl_3 = 0, s_tl_4 = 0;
char tc=0;	// tc=0 teplota, tc!=0 cas
char tep_min1 = 37, tep_min2 = 0, tep_max1 = 38, tep_max2 = 0;	// nastavene teploty
char buffer[16];
uint8_t digit1=0, digit2=0;			//promenna pro cele cislo teploty
uint16_t decimal1=0, decimal2=0;	//promenna pro desetine cislo teploty
char min_l=0, min_h=0, hod_l=0, hod_h=0;
char hod=12, min=30, hod_old = 12, cas_roz = 0;
unsigned char BCD;
unsigned char mot_flag = 0;		// priznak behu motoru 0/1 = stoji/bezi
unsigned char smer_flag = 0;	// priznak smeru motoru 0/1 = smer1/smer2

/*
** DEKLARACE VEDLEJSICH FUNKCI
*/
void read_temperature1(char *buffer);	//fce pro cteni teploty z cidla 1
void read_temperature2(char *buffer);	//fce pro cteni teploty z cidla 2
void topeni(uint8_t dig1, uint8_t dig2, uint16_t dec1, uint16_t dec2);	// spousti/vypina topidlo
void vetrak(uint8_t dig1, uint8_t dig2, uint16_t dec1, uint16_t dec2);	// rychlost otaceni vetraku
unsigned char bin_to_bcd(char bin);	// fce pro prevod binar. cisla na bcd
unsigned char bcd_to_bin(char bcd_i);
unsigned char read(unsigned char bunka);
void write(unsigned char bcd_i, unsigned char bunka);

/*
** HLAVNI FUNKCE
*/
int main( void )
{
    i2c_init();				// inicializace TWI
	lcd_init();				// inicializace disp
    lcd_clrscr();			// smazani displeje
	nastav_porty();			// nastaveni smerovych registru
	nastav_16b_cit_cas();	// nastaveni ridicich registru C/C
	nastav_cit_cas0;		// nastaveni ridicich registru C/C0
	nastav_cit_cas2;		// nastaveni ridicich registru C/C2
	sei();					// globalni povoleni preruseni
	
	// vlozeni predefinovanych hodnot do RTC
	BCD = bin_to_bcd(hod);
	write(BCD,hod_adr);
	BCD = bin_to_bcd(min);
	write(BCD,min_adr);    

	while(1)
	{
		// zobrazovani a nastavovani teplot
		if(tc==0)	
		{
			switch(s_tl_2)
			{
				// zobrazeni teplot
				case 0: read_temperature1(buffer);	//nacteni teploty z cidla 1 do gl.prom
						read_temperature2(buffer);	//nacteni teploty z cidla 1 do gl.prom
						
						//zobrazeni teploty1 na display
 						if (digit1>=127)
 						{
  							lcd_gotoxy(0,0);
 							lcd_putc('-');
 						}
 						lcd_gotoxy(1,0);
 						sprintf(buffer, "%d.%d  ", digit1, decimal1);
 						lcd_puts(buffer);
 					
						//zobrazeni teploty2 na display
 						if (digit2>=127)
 						{
  							lcd_gotoxy(0,1);
 							lcd_putc('-');
 						}
 						lcd_gotoxy(1,1);
 						sprintf(buffer, "%d.%d  ", digit2, decimal2);
 						lcd_puts(buffer);

						if((s_tl_3 != 0) && (s_tl_4 ==0))	//jestlize bylo stisknuto tlacitko 3 
															//a zaroven nebylo stisk. tlacitko 4 
						{
							PORTC |= _BV(PORTC4);	// rozsviceni podsviceni lcd
							s_tl_3 = 0;	//vynulovani detekce stisku tlacitka
							s_tl_4 = 0;	//vynulovani detekce stisku tlacitka
						}

						if((s_tl_4 != 0) && (s_tl_3 ==0))	//jestlize bylo stisknuto tlacitko 4 
															//a zaroven nebylo stisk. tlacitko 3
						{
							PORTC &= ~(_BV(PORTC4));	// rozsviceni podsviceni lcd
							s_tl_3 = 0;	//vynulovani detekce stisku tlacitka
							s_tl_4 = 0;	//vynulovani detekce stisku tlacitka
						}
				break;
				
				// nastaveni teploty pri ktere sepne topidlo (stupne)
				case 1: lcd_gotoxy(0, 0);	//poloha kurzoru
 						lcd_puts("Tmin st "); //vypsany retezec
						
						if((s_tl_3 != 0) && (s_tl_4 ==0))	//jestlize bylo stisknuto tlacitko 3 
															//a zaroven nebylo stisk. tlacitko 4 
						{
							tep_min1 += s_tl_3;
							if(tep_min1 == 100) tep_min1 = 0;
							lcd_gotoxy(0,1);
							sprintf(buffer, " %d.%d ", tep_min1, tep_min2);
 							lcd_puts(buffer);
							s_tl_3 = 0;	//vynulovani detekce stisku tlacitka
							s_tl_4 = 0;	//vynulovani detekce stisku tlacitka
						}
						
						if((s_tl_4 != 0) && (s_tl_3 ==0))	//jestlize bylo stisknuto tlacitko 4 
															//a zaroven nebylo stisk. tlacitko 3
						{
							if(tep_min1 == 0) tep_min1 = 100;
							tep_min1 -= s_tl_4;
							lcd_gotoxy(0,1);
							sprintf(buffer, " %d.%d ", tep_min1, tep_min2);
 							lcd_puts(buffer);
							s_tl_3 = 0;	//vynulovani detekce stisku tlacitka
							s_tl_4 = 0;	//vynulovani detekce stisku tlacitka
						}
				break;

				// nastaveni teploty pri ktere sepne topidlo (desetiny stupne)
				case 2: lcd_gotoxy(0, 0);	//poloha kurzoru
 						lcd_puts("Tmin des"); //vypsany retezec

						if((s_tl_3 != 0) && (s_tl_4 ==0))	//jestlize bylo stisknuto tlacitko 3 
															//a zaroven nebylo stisk. tlacitko 4 
						{
							tep_min2 += s_tl_3;
							if(tep_min2 == 100) tep_min1 = 0;
							lcd_gotoxy(0,1);
							sprintf(buffer, " %d.%d ", tep_min1, tep_min2);
 							lcd_puts(buffer);
							s_tl_3 = 0;	//vynulovani detekce stisku tlacitka
							s_tl_4 = 0;	//vynulovani detekce stisku tlacitka
						}
						
						if((s_tl_4 != 0) && (s_tl_3 ==0))	//jestlize bylo stisknuto tlacitko 4 
															//a zaroven nebylo stisk. tlacitko 3
						{
							if(tep_min2 == 0) tep_min1 = 100;
							tep_min2 -= s_tl_4;
							lcd_gotoxy(0,1);
							sprintf(buffer, " %d.%d ", tep_min1, tep_min2);
 							lcd_puts(buffer);
							s_tl_3 = 0;	//vynulovani detekce stisku tlacitka
							s_tl_4 = 0;	//vynulovani detekce stisku tlacitka
						}
				break;

				// nastaveni teploty pri ktere vypne topidlo (stupne)
				case 3: lcd_gotoxy(0, 0);	//poloha kurzoru
 						lcd_puts("Tmax st "); //vypsany retezec

						if((s_tl_3 != 0) && (s_tl_4 ==0))	//jestlize bylo stisknuto tlacitko 3 
															//a zaroven nebylo stisk. tlacitko 4 
						{
							tep_max1 += s_tl_3;
							if(tep_max1 == 100) tep_min1 = 0;
							lcd_gotoxy(0,1);
							sprintf(buffer, " %d.%d ", tep_max1, tep_max2);
 							lcd_puts(buffer);
							s_tl_3 = 0;	//vynulovani detekce stisku tlacitka
							s_tl_4 = 0;	//vynulovani detekce stisku tlacitka
						}
						
						if((s_tl_4 != 0) && (s_tl_3 ==0))	//jestlize bylo stisknuto tlacitko 4 
															//a zaroven nebylo stisk. tlacitko 3
						{
							if(tep_max1 == 0) tep_min1 = 100;
							tep_max1 -= s_tl_4;
							lcd_gotoxy(0,1);
							sprintf(buffer, " %d.%d ", tep_max1, tep_max2);
 							lcd_puts(buffer);
							s_tl_3 = 0;	//vynulovani detekce stisku tlacitka
							s_tl_4 = 0;	//vynulovani detekce stisku tlacitka
						}
				break;

				// nastaveni teploty pri ktere vypne topidlo (desetiny stupne)
				case 4: lcd_gotoxy(0, 0);	//poloha kurzoru
 						lcd_puts("Tmax des"); //vypsany retezec

						if((s_tl_3 != 0) && (s_tl_4 ==0))	//jestlize bylo stisknuto tlacitko 3 
															//a zaroven nebylo stisk. tlacitko 4 
						{
							tep_max2 += s_tl_3;
							if(tep_max2 == 100) tep_min1 = 0;
							lcd_gotoxy(0,1);
							sprintf(buffer, " %d.%d ", tep_max1, tep_max2);
 							lcd_puts(buffer);
							s_tl_3 = 0;	//vynulovani detekce stisku tlacitka
							s_tl_4 = 0;	//vynulovani detekce stisku tlacitka
						}
						
						if((s_tl_4 != 0) && (s_tl_3 ==0))	//jestlize bylo stisknuto tlacitko 4 
															//a zaroven nebylo stisk. tlacitko 3
						{
							if(tep_max2 == 0) tep_min1 = 100;
							tep_max2 -= s_tl_4;
							lcd_gotoxy(0,1);
							sprintf(buffer, " %d.%d ", tep_max1, tep_max2);
 							lcd_puts(buffer);
							s_tl_3 = 0;	//vynulovani detekce stisku tlacitka
							s_tl_4 = 0;	//vynulovani detekce stisku tlacitka
						}
				break;

				// zpet k zobrazeni teploty
				case 5: s_tl_2 = 0;
						lcd_clrscr();		// smazani displeje
				break;
			}
			
			if(s_tl_1==1)
			{
				tc=1;
				lcd_clrscr();		// smazani displeje
				s_tl_1=0;
				s_tl_2=0;
			}
		}
		// zobrazovani a nastavovani casu
		else	
		{
			switch(s_tl_2)
			{
				// zobrazeni casu
				case 0: lcd_gotoxy(0, 0);		//poloha kurzoru
 						lcd_puts("Cas     ");	//vypsany retezec
						
						BCD = read(hod_adr);
						hod = bcd_to_bin(BCD);
						BCD = read(min_adr);
						min = bcd_to_bin(BCD);
					
						lcd_gotoxy(0,1);
						sprintf(buffer, "%2d:%2d  ", hod, min);
						lcd_puts(buffer);
						
						if((s_tl_3 != 0) && (s_tl_4 ==0))	//jestlize bylo stisknuto tlacitko 3 
															//a zaroven nebylo stisk. tlacitko 4 
						{
							PORTC |= _BV(PORTC4);	// rozsviceni podsviceni lcd
							s_tl_3 = 0;	//vynulovani detekce stisku tlacitka
							s_tl_4 = 0;	//vynulovani detekce stisku tlacitka
						}

						if((s_tl_4 != 0) && (s_tl_3 ==0))	//jestlize bylo stisknuto tlacitko 4 
															//a zaroven nebylo stisk. tlacitko 3
						{
							PORTC &= ~(_BV(PORTC4));	// rozsviceni podsviceni lcd
							s_tl_3 = 0;	//vynulovani detekce stisku tlacitka
							s_tl_4 = 0;	//vynulovani detekce stisku tlacitka
						}
				break;

				// nastaveni hodin
				case 1: lcd_gotoxy(0, 0);	//poloha kurzoru
 						lcd_puts("hodiny  "); //vypsany retezec

						if((s_tl_3 != 0) && (s_tl_4 ==0))	//jestlize bylo stisknuto tlacitko 3 
															//a zaroven nebylo stisk. tlacitko 4 
						{
							hod += s_tl_3;
							if(hod == 24) hod = 0;
							lcd_gotoxy(0,1);
							sprintf(buffer, "%2d:%2d  ", hod, min);
 							lcd_puts(buffer);
							s_tl_3 = 0;	//vynulovani detekce stisku tlacitka
							s_tl_4 = 0;	//vynulovani detekce stisku tlacitka
						}
						
						if((s_tl_4 != 0) && (s_tl_3 ==0))	//jestlize bylo stisknuto tlacitko 4 
															//a zaroven nebylo stisk. tlacitko 3
						{
							if(hod == 0) hod = 24;
							hod -= s_tl_4;
							lcd_gotoxy(0,1);
							sprintf(buffer, "%2d:%2d  ", hod, min);
 							lcd_puts(buffer);
							s_tl_3 = 0;	//vynulovani detekce stisku tlacitka
							s_tl_4 = 0;	//vynulovani detekce stisku tlacitka
						}
				break;
				
				//ulozeni hodnoty hodin
				case 2: BCD = bin_to_bcd(hod);
						write(BCD,hod_adr);
						hod_old = hod;		// nastaveni hodnoty pro otaceni motoru

						lcd_gotoxy(0,1);
						lcd_puts("ulozeno ");
				break;
				
				// nastaveni minut
				case 3: lcd_gotoxy(0, 0);		// poloha kurzoru
 						lcd_puts("minuty  ");   // vypsany retezec
						
						if((s_tl_3 != 0) && (s_tl_4 ==0))	// jestlize bylo stisknuto tlacitko 3 
															// a zaroven nebylo stisk. tlacitko 4 
						{
							min += s_tl_3;
							if(min == 60) min = 0;
							lcd_gotoxy(0,1);
							sprintf(buffer, "%2d:%2d  ", hod, min);
 							lcd_puts(buffer);
							s_tl_3 = 0;	// vynulovani detekce stisku tlacitka
							s_tl_4 = 0;	// vynulovani detekce stisku tlacitka
						}
						
						if((s_tl_4 != 0) && (s_tl_3 ==0))	//jestlize bylo stisknuto tlacitko 4 
															//a zaroven nebylo stisk. tlacitko 3
						{
							if(min == 0) min = 60;
							min -= s_tl_4;
							lcd_gotoxy(0,1);
							sprintf(buffer, "%2d:%2d  ", hod, min);
 							lcd_puts(buffer);
							s_tl_3 = 0;	//vynulovani detekce stisku tlacitka
							s_tl_4 = 0;	//vynulovani detekce stisku tlacitka
						}
				break;
				
				// ulozeni hodnoty minut
				case 4: BCD = bin_to_bcd(min);
						write(BCD,min_adr);

						lcd_gotoxy(0,1);
						lcd_puts("ulozeno ");
				break;

				// navrat na zobrazeni casu
				case 5: s_tl_2 = 0;
				break; 
			}
			if(s_tl_1==1)
			{
				tc=0;
				lcd_clrscr();		// smazani displeje
				s_tl_1=0;
				s_tl_2=0;
			}
		}
	}
//----------------------------------------------------------------------
	// zapnuti/vypnuti topeni (zavislost na teplote)
	topeni(digit1, digit2, decimal1, decimal2);

//----------------------------------------------------------------------
	// ventilator (zavislost na teplote)
	vetrak(digit1, digit2, decimal1, decimal2);

//----------------------------------------------------------------------
	// otaceni vajicek (zavislost na case)

	BCD = read(hod_adr);		// nacteni casu z RTC
	hod = bcd_to_bin(BCD);		// prevod casu do int
	cas_roz = hod - hod_old;	// vypocet rozdilu casu

	if(hod < hod_old)	// jestli ze cas prehoupne 24hod 
	{
		if((SW6_MOT != 0) && (SW7_MOT != 0)) // jestlize neni sepnut sw6
		{									 // a zaroven neni sepnut sw7
		// pocatecni rozjezd ze stredu
			mot_smer1;		// prikaz pro smer motoru
			smer_flag = 0;	// priznak pro smer1
		} 		

		if((SW6_MOT == 0) && (SW7_MOT != 0)) // jestlize je sepnut sw6
		{									 // a zaroven neni sepnut sw7
			mot_smer1;		// prikaz pro smer motoru
			smer_flag = 0;	// priznak pro smer1
				
		} 
														
		if((SW7_MOT == 0) && (SW6_MOT != 0)) 	// jestlize je sepnut sw7
		{										// a zaroven neni sepnut sw6
			mot_smer2;		// prikaz pro smer motoru
			smer_flag = 1;	// priznak pro smer1
		} 

		mot_zap;		// zapnuti motoru
		mot_flag = 1;	// priznak zapnuti motoru
		hod_old = hod;	// aktualizace po pretoceni
	}
	else if(cas_roz == CAS_OTOC)	// jestlize uz je cas na otoceni
	{
		if((SW6_MOT != 0) && (SW7_MOT != 0)) // jestlize neni sepnut sw6
		{									 // a zaroven neni sepnut sw7
		// pocatecni rozjezd ze stredu
			mot_smer1;		// prikaz pro smer motoru
			smer_flag = 0;	// priznak pro smer1
		} 

		if((SW6_MOT == 0) && (SW7_MOT != 0)) // jestlize je sepnut sw6
		{									 // a zaroven neni sepnut sw7
			mot_smer1;		// prikaz pro smer motoru
			smer_flag = 0;	// priznak pro smer1
				
		} 
														
		if((SW7_MOT == 0) && (SW6_MOT != 0)) 	// jestlize je sepnut sw7
		{										// a zaroven neni sepnut sw6
			mot_smer2;		// prikaz pro smer motoru
			smer_flag = 1;	// priznak pro smer1
		} 

		mot_zap;		// zapnuti motoru
		mot_flag = 1;	// priznak zapnuti motoru
		hod_old = hod;	// aktualizace po pretoceni
	}
	else
	{
		if((SW6_MOT == 0) && (SW7_MOT == 0)) // jestlize je sepnut sw6
		{									 // a zaroven je sepnut sw7
		// zakazany stav, proto se motor vypne
			mot_vyp;		// vypnuti motoru
			mot_flag = 0;	// priznak vypnuti motoru
		} 

		if((SW7_MOT == 0) && (smer_flag == 0))	 // dojezd z leva do prava
		{										
			mot_vyp;		// vypnuti motoru
			mot_flag = 0;	// priznak vypnuti motoru
		} 

		if((SW6_MOT == 0) && (smer_flag == 1))	 // dojezd z prava do leva
		{										 
			mot_vyp;		// vypnuti motoru
			mot_flag = 0;	// priznak vypnuti motoru
		} 
	}
//----------------------------------------------------------------------
}

/*
** PRERUSENI
*/
ISR(TIMER1_COMPA_vect)	//fce preruseni pri rovnosti citace/casovace1
{
	if (bit_is_clear(TL1_PORT,TL1_BIT)) s_tl_1++;	// 
	if (bit_is_clear(TL2_PORT,TL2_BIT)) s_tl_2++;
	if (bit_is_clear(TL3_PORT,TL3_BIT)) s_tl_3++;
	if (bit_is_clear(TL4_PORT,TL4_BIT)) s_tl_4++;
	TCNT1=0;	// ted bude citat zase od zacatku
}

/*
** VEDLEJSI FUNKCE
*/
//------cteni teploty1------
void read_temperature1(char *buffer){
 uint8_t temperature[2];

//Reset, skip ROM and start temperature conversion
 therm_reset();
 therm_write_byte(SKIP_ROM);
 therm_write_byte(CONVERT_T);

//Wait until conversion is complete
 while(!therm_read_bit()); //DS18B20 send 1 for conversion is done

//Reset, skip ROM and send command to read Scratchpad
 therm_reset();
 therm_write_byte(SKIP_ROM);
 therm_write_byte(READ_SCRAT);

//Read Scratchpad (only 2 first bytes)
 temperature[0]=therm_read_byte();		//low byte
 temperature[1]=therm_read_byte();		//high byte

 therm_reset();

//conversion 2 byte to digit and decimal
 
 digit1 = (temperature[1]<<4)&0xf0;		//form 2 bytes to byte for conversion
 digit1 |= (temperature[0]&0xf0)>>4;

 decimal1 = (temperature[0]&0xf)*625;		//625 create whole number (over 8b therefore uint16_t)
 decimal1 /= 100;	//only 2 decimal place (1000 - one decimal place)
}

//------cteni teploty2------
void read_temperature2(char *buffer){
 uint8_t temperature[2];

//Reset, skip ROM and start temperature conversion
 therm_reset2();
 therm_write_byte2(SKIP_ROM);
 therm_write_byte2(CONVERT_T);

//Wait until conversion is complete
 while(!therm_read_bit2()); //DS18B20 send 1 for conversion is done

//Reset, skip ROM and send command to read Scratchpad
 therm_reset2();
 therm_write_byte2(SKIP_ROM);
 therm_write_byte2(READ_SCRAT);

//Read Scratchpad (only 2 first bytes)
 temperature[0]=therm_read_byte2();		//low byte
 temperature[1]=therm_read_byte2();		//high byte

 therm_reset2();

//conversion 2 byte to digit and decimal
 
 digit2 = (temperature[1]<<4)&0xf0;		//form 2 bytes to byte for conversion
 digit2 |= (temperature[0]&0xf0)>>4;

 decimal2 = (temperature[0]&0xf)*625;		//625 create whole number (over 8b therefore uint16_t)
 decimal2 /= 100;	//only 2 decimal place (1000 - one decimal place)
}

//--------zapnuti vypnuti topeni-----------
void topeni(uint8_t dig1, uint8_t dig2, uint16_t dec1, uint16_t dec2)
{
	uint8_t aver_dig;
	uint16_t aver_dec;

	aver_dig = (dig1 + dig2)/2;		//zjisteni prumeru jednotek stupnu
	aver_dec = (dec1 + dec2)/2;	//zjisteni prumeru desetin stupnu

	if((aver_dig >= tep_max1) && (aver_dec >= tep_max2))
	{
	  	RELE_PORT |= _BV(RELE_BIT1);	
		RELE_PORT &= ~(_BV(RELE_BIT2));
	}
	else if((aver_dig <= tep_min1) && (aver_dec <= tep_min1))
	{
		RELE_PORT |= _BV(RELE_BIT2);	
		RELE_PORT &= ~(_BV(RELE_BIT1));
	} 									
}

//-------- rychlost otaceni vetraku -----------
void vetrak(uint8_t dig1, uint8_t dig2, uint16_t dec1, uint16_t dec2)
{
	uint8_t div_dig;
	uint16_t div_dec;

	div_dig = dig1 - dig2;		//zjisteni rozdilu jednotek stupnu
	div_dec = dec1 - dec2;	//zjisteni rozdilu desetin stupnu

	if(div_dig>=2) 						 	 OCR0 = 255;	// pwm 100%
	else if((div_dig>=1) && (div_dec >= 50)) OCR0 = 225;	// pwm 90%
	else if(div_dig>=1) 					 OCR0 = 200;	// pwm 80%
	else if(div_dec >= 80) 					 OCR0 = 175;	// pwm 70%
	else if(div_dec >= 60)					 OCR0 = 150;	// pwm 60%
	else if(div_dec >= 50)					 OCR0 = 125;	// pwm 50%
	else if(div_dec >= 40)					 OCR0 = 100;	// pwm 40%
	else if(div_dec >= 30)					 OCR0 = 75;		// pwm 30%
	else if(div_dec >= 20)					 OCR0 = 50;		// pwm 20%
	else 									 OCR0 = 25;		// pwm 10%
}

// fce pro prevod binar. cisla na bcd
unsigned char bin_to_bcd(char bin)	
{
	int temp = bin;
	unsigned char bcd_i, dig_1, dig_0;

	dig_1 = temp/10; 
  	temp  = temp - (dig_1 * 10); 
   	dig_0 = temp;

	bcd_i = (((dig_1 <<4) & 0xF0) | (dig_0 & 0x0F));
	return bcd_i;
}
// fce pro prevod z bcd kodu na binarni
unsigned char bcd_to_bin(char bcd_i)	// fce pro prevod binar. cisla na bcd
{
	int temp = bcd_i;
	unsigned char bin_i, dig_1, dig_0;

	dig_0 = 0x0f & temp;
	dig_1 = (temp >> 4) & 0x0f;

	bin_i = dig_0 + (dig_1 * 10);
	return bin_i;
}

/*
** KONEC KODU
*/
